from django.db import models
from django.urls import reverse

class Announcement(models.Model):
    title = models.CharField(max_length = 50)
    body = models.TextField()
    author = models.ForeignKey("dashboard.WidgetUser", on_delete=models.CASCADE)
    pub_datetime = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return self.title
    
    def get_absolute_url(self):
        return reverse("announcement-details", kwargs={'pk': self.pk})

    def datetime(self):
        return self.pub_datetime.strftime("%m/%d/%Y, %I:%M %p")

class Reaction(models.Model):
    Like = 'Like'
    Love = 'Love'
    Angry = 'Angry'
    mode_options = [
        (Like, 'Like'), 
        (Love, 'Love'),
        (Angry, 'Angry'),
    ]
    name = models.CharField(max_length = 50, choices=mode_options, default=Like)
    tally = models.IntegerField(default = 0)
    announcement = models.ForeignKey(Announcement, on_delete=models.CASCADE)

    def __str__(self):
        return self.name