from django.db import models
from django.urls import reverse

class Location(models.Model):
    Onsite = 'Onsite'
    Online = 'Online'
    Hybrid = 'Hybrid'
    mode_options = [
        (Onsite, 'Onsite'), 
        (Online, 'Online'),
        (Hybrid, 'Hybrid'),
    ]
    modes = models.CharField(max_length = 50, choices=mode_options, default=Onsite)
    venue = models.CharField(max_length = 50)

    def __str__(self):
        return self.modes + " - " + self.venue
    
class Event(models.Model):
    activity = models.CharField(max_length = 50)
    target_datetime = models.DateTimeField()
    estimated_hours = models.FloatField(default=0)
    locations = models.ForeignKey(Location, on_delete=models.CASCADE)
    course = models.ForeignKey('assignments.Course', on_delete=models.CASCADE)

    def __str__(self):
        return self.activity
    
    def datetime(self):
        return self.target_datetime.strftime("%m/%d/%Y, %I:%M %p")
    
    def get_absolute_url(self):
        return reverse("event-details", kwargs={'pk': self.pk})